# ocrmypdfgui
I use James R. Barlow's OCRmyPDF heavily in my paperless Office and have created this Python Project as a GUI wrapper to run batch jobs on my filesystem. This is strictly a Hobby Project and is not "official". Feel free to use it if you like.

Icons made by Freepik from www.flaticon.com

# Installation
You can find the most up-to-date version of ocrmypdfgui on pypi which is based on GTK3.
<code>pip install ocrmypdfgui</code>

There is also an (older) tkinter based version snap package on snapcraft.io:  
[![Get it from the Snap Store](https://snapcraft.io/static/images/badges/en/snap-store-black.svg)](https://snapcraft.io/ocrmypdfgui)

or you can get if from the commandline:
<code>sudo snap install ocrmypdfgui</code>
